// 	Copyright  1992 by Apple Computer, Inc.  All rights reserved. 
// 	MouseInfo.r file.
//	Kent Sandvik DTS
//	This file contains all the normal MacApp resources,
//	Version Info (latest first):
//
//	<1>		khs		1.0		First final version
//	<2>		khs		1.0.1	Fixed a memory leak in TMapApplication::GetSleepValue()


// INCLUDES 

#ifndef __TYPES.R__
#include "Types.r"
#endif

#ifndef __SYSTYPES.R__
#include "SysTypes.r"				// needed for version resource
#endif		

#ifndef __MacAppTypes__
#include "MacAppTypes.r"
#endif

#if qTemplateViews
#ifndef __ViewTypes__
#include "ViewTypes.r"
#endif
#endif

#ifndef __FloatWindow__
#include "FloatWindow.r"
#endif

#if qDebug
include "Debug.rsrc";
#endif


#ifndef __RESOURCECONSTANTS__
#include "ResourceConstants.h"			// common header file for resource IDs
#endif


// RESOURCES FILES

include "MacApp.rsrc";					// default MacApp resources
include "Dialog.rsrc";


// CODE 

#if !qPowerPC
include $$Shell("ObjApp")"MouseInfo" 'CODE';
#endif

// CONSTANTS

// Finder Information

#define kApplicationName				$$Shell("XAppName")


// SIZE

resource 'SIZE' (-1) {
	saveScreen,
	acceptSuspendResumeEvents,
	enableOptionSwitch,
	canBackground,
	doesActivateOnFGSwitch,
	backgroundAndForeground,
	dontGetFrontClicks,
	ignoreAppDiedEvents,
	is32BitCompatible,
	isHighLevelEventAware,
	localAndRemoteHLEvents,
	isStationeryAware,				
	reserved,
	reserved,
	reserved,
	reserved,
#if qModelFarCode
	1550 * 1024,
	1500 * 1024,
#elif qDebug
	1500 * 1024,
	1475 * 1024
#else
	1375 * 1024,
	1350 * 1024
#endif
};

/*--------------------------------------------------------------------------------
	memory stuff
--------------------------------------------------------------------------------*/
resource 'mem!' (132,
#if qNames
	"Additional Stack Space",
#endif
	purgeable) {
	0,				// Add to object heap size
	0,				// Add to heap increment size
	0,				// Add to temporary reserve
	0,				// Add to permanent reserve
	49152			// Add to stack space
};



/*	Printing to the LaserWriter is the time when the most temporary memory
	is in use.  We need the segments in use at that time */

resource 'seg!' (256, purgeable) {
	{
		"GNonRes";
		"GClipboard";
		"GClose";
		"GFile";
		"GOpen";
		"GReadFile";
		"GSelCommand";
		"GFinder";
		"GWriteFile";
		"BBNonRes";
		"BBOpen";
		"GNonRes2";
		"GPrint";
		"GReadResource";
		"TESelCommand";
	}
};

#if qPowerPC
#include "CodeFragmentTypes.r"

resource 'cfrg' (0, "Configuration Info") {
	{
		kPowerPC,
		kFullLib,
		kNoVersionNum,
		kNoVersionNum,
		0,
		0,
		kIsApp,
		kOnDiskFlat,
		kZeroOffset,
		kWholeFork,
		"MouseInfo"
	}
};
#endif


// VERS

// Version for MouseInfo

RESOURCE 'vers' (1,
#if qNames
	"Application Version",
#endif
	purgeable) {
	0x01,
	0x00,
	final,
	0x01,
	verUs,
	"1.0.1",
	"1.0.1, Application created by MacApp and Mountain Dew"
};



// ICONs and BUNDLE
// Get the default MacApp application icon and file reference

include "Defaults.rsrc"  'ICN#' (128);


// CMNUs 

include "Defaults.rsrc" 'CMNU' (mApple);			// grab the default Apple/File menus

resource 'CMNU' (mFile,
#if qNames
"mFile",
#endif
nonpurgeable) {
	mFile,
	textMenuProc,
	EnablingManagedByMacApp,
	enabled,
	"File",
	{
	"New",				noIcon, "N",	noMark, plain, cNew;
	"Close",			noIcon, "W",	noMark, plain, cClose;
	"-",				noIcon, noKey,	noMark, plain, nocommand;
	"Quit",				noIcon, "Q",	noMark, plain, cQuit
	}
};

resource 'CMNU' (mWindows,
#if qNames
"mWindows",
#endif
nonpurgeable
) {
	mWindows,
	textMenuProc,
	EnablingManagedByMacApp,
	enabled,
	"Windows",
	{
	}
};

resource 'CMNU' (mMouseTrack,
#if qNames
"mMouseTrack",
#endif
nonpurgeable
) {
	mMouseTrack,
	textMenuProc,
	EnablingManagedByMacApp,
	enabled,
	"Mouse Tracking",
	{
	"Open Tracker",	noIcon, "T", noMark, plain, cOpenTracker
	}
};


// MBARs 
// Displayed menus 

resource 'MBAR' (kMBarDisplayed,
#if qNames
"Windoid",
#endif
	purgeable) {
	{mApple; mFile; mWindows; mMouseTrack }
};


//--------------------------------------------------------------------------------------------------
// 	Icons, Bundles and FRefs


type kSignature as 'STR ';
resource kSignature (0,
#if qNames
"Signature",
#endif
	purgeable) {
	"MouseInfo 1.0.1 Apple Computer, Inc. 1992"
};

resource 'FREF' (kApplicationID,
#if qNames
"MouseInfo Application",
#endif
	purgeable) {
	'APPL',
	0,
	""
};

resource 'FREF' (kDocumentID,
#if qNames
"MouseInfo Document",
#endif
	purgeable) {
	kFileType,
	1,
	""
};

resource 'FREF' (kStationeryID,
#if qNames
"MouseInfo Stationery",
#endif
	purgeable) {
	kStationery,
	2,
	""
};

resource 'BNDL' (kBundleID,
#if qNames
"MouseInfo",
#endif
	purgeable) {
	kSignature,
	0,
	{ /* array TypeArray: 2 elements */
		/* [1] */
		'ICN#',
		{ /* array IDArray: 3 elements */
			0, kApplicationID,
			1, kDocumentID,
			2, kStationeryID
		},
		/* [2] */
		'FREF',
		{ /* array IDArray: 3 elements */
			0, kApplicationID,
			1, kDocumentID,
			2, kStationeryID
		}
	}
};


// STR# and TxSt resources:


resource 'STR#' (1006, "Window titles", purgeable) {
	{	/* array StringArray: 2 elements */
		/* [1] */
		"",
		/* [2] */
		"Mouse"
	}
};

resource 'STR#' (1005, "Static Text text", purgeable) {
	{	/* array StringArray: 5 elements */
		/* [1] */
		"Mouse Location:",
		/* [2] */
		"Mouse State:",
		/* [3] */
		"v:",
		/* [4] */
		"h:",
		/* [5] */
		""
	}
};

resource 'TxSt' (1000, purgeable) {
	tsPlain,
	9,
	{	/* array: 3 elements */
		/* [1] */
		0x0,
		/* [2] */
		0x0,
		/* [3] */
		0x0
	},
	"Geneva"
};

resource 'TxSt' (1001, purgeable) {
	tsBold,
	9,
	{	/* array: 3 elements */
		/* [1] */
		0x0,
		/* [2] */
		0x0,
		/* [3] */
		0x0
	},
	"Geneva"
};


resource 'View' (1002, "window") {MAThreeOh, 
	{
	ViewSignatureAndClassname
		{'wind', 202, "TMenuedWindow", 'WIND', enabled, noIdle, {}, MAThreeOh, 
		{45, 45}, {277, 375}, sizeFixed, sizeFixed, notShown, doesntWantToBeTarget, 
		handlesCursor, letsSubViewsHandleCursor, noCursorID, 
		handlesHelp, letsSubViewsHandleHelp, noHelpID, 1, 
		NoDrawingEnvironment {}, 
		AdornerListSignatureAndClassname {NoIdentifier, AdornerList, AdornerElementSize, AdornerElementSizeShift, DynamicArrayAllocationIncrement, {
			AdornFirst, AdornerLocalObject {EraseAdorner}, 
			DrawView, AdornerLocalObject {DrawAdorner}}}, emptyUserArea, 
		Window {noGrowDocProc, noID, goAwayBox, notResizable, ignoreFirstClick, 
			freeOnClosing, disposeOnFree, closesDocument, openWithDocument, dontAdaptToScreen, stagger, forceOnScreen, 
			dontCenter, doesntFloat, doesntHideOnSuspend, generateActivates, filler, 1006, 1}, 1}, 
	ViewSignatureAndClassname
		{'view', 62, "", 'vie1', enabled, noIdle, {}, MAThreeOh, 
		{4, 5}, {267, 365}, sizeVariable, sizeVariable, shown, doesntWantToBeTarget, 
		handlesCursor, letsSubViewsHandleCursor, noCursorID, 
		handlesHelp, letsSubViewsHandleHelp, noHelpID, 1, 
		NoDrawingEnvironment {}, 
		NoAdorners {}, emptyUserArea, 
		View {}, 
		NoSubviews}
	}
};

resource 'View' (1003, "Float Window") {MAThreeOh, 
	{
	ViewSignatureAndClassname
		{'ttrk', 879, "TTrackWindow", 'WIND', enabled, noIdle, {}, MAThreeOh, 
		{45, 45}, {92, 95}, sizeVariable, sizeVariable, shown, doesntWantToBeTarget, 
		handlesCursor, letsSubViewsHandleCursor, noCursorID, 
		handlesHelp, letsSubViewsHandleHelp, noHelpID, 1, 
		NoDrawingEnvironment {}, 
		AdornerListSignatureAndClassname {NoIdentifier, AdornerList, AdornerElementSize, AdornerElementSizeShift, DynamicArrayAllocationIncrement, {
			AdornFirst, AdornerLocalObject {EraseAdorner}, 
			DrawView, AdornerLocalObject {DrawAdorner}}}, emptyUserArea, 
		FloatWindow { kWindoidWDEF + kWindoidNotResizable, noID, goAwayBox, notresizable, doFirstClick, 
			freeOnClosing, disposeOnFree, doesntCloseDocument, dontOpenWithDocument, dontAdaptToScreen, dontStagger, forceOnScreen, 
			centerHorizontally, floats, hidesOnSuspend, doesntGenerateActivates, 0, 1006, 2}, 7}, 
		ViewSignatureAndClassname
		{'stat', 96, "", 'stat', notEnabled, noIdle, {}, MAThreeOh, 
		{7, 1}, {12, 84}, sizeVariable, sizeVariable, shown, doesntWantToBeTarget, 
		handlesCursor, letsSubViewsHandleCursor, noCursorID, 
		handlesHelp, letsSubViewsHandleHelp, noHelpID, 1, 
		NoDrawingEnvironment {}, 
		NoAdorners {}, emptyUserArea, 
		StaticText {mStaticTextHit, notHilited, notDimmed, sizeable, noInset, 1000, dontPreferOutline, autoWrap, dontEraseFirst, justSystem, 1005, 1}, 
		NoSubviews}, 
	ViewSignatureAndClassname
		{'stat', 96, "", 'sta0', notEnabled, noIdle, {}, MAThreeOh, 
		{48, 1}, {12, 84}, sizeVariable, sizeVariable, shown, doesntWantToBeTarget, 
		handlesCursor, letsSubViewsHandleCursor, noCursorID, 
		handlesHelp, letsSubViewsHandleHelp, noHelpID, 1, 
		NoDrawingEnvironment {}, 
		NoAdorners {}, emptyUserArea, 
		StaticText {mStaticTextHit, notHilited, notDimmed, sizeable, noInset, 1000, dontPreferOutline, autoWrap, dontEraseFirst, justSystem, 1005, 2}, 
		NoSubviews}, 
	ViewSignatureAndClassname
		{'stat', 96, "", 'sta1', notEnabled, noIdle, {}, MAThreeOh, 
		{23, 4}, {16, 15}, sizeVariable, sizeVariable, shown, doesntWantToBeTarget, 
		handlesCursor, letsSubViewsHandleCursor, noCursorID, 
		handlesHelp, letsSubViewsHandleHelp, noHelpID, 1, 
		NoDrawingEnvironment {}, 
		NoAdorners {}, emptyUserArea, 
		StaticText {mStaticTextHit, notHilited, notDimmed, sizeable, noInset, 1000, dontPreferOutline, autoWrap, dontEraseFirst, justSystem, 1005, 3}, 
		NoSubviews}, 
	ViewSignatureAndClassname
		{'stat', 96, "", 'sta2', notEnabled, noIdle, {}, MAThreeOh, 
		{23, 49}, {16, 15}, sizeVariable, sizeVariable, shown, doesntWantToBeTarget, 
		handlesCursor, letsSubViewsHandleCursor, noCursorID, 
		handlesHelp, letsSubViewsHandleHelp, noHelpID, 1, 
		NoDrawingEnvironment {}, 
		NoAdorners {}, emptyUserArea, 
		StaticText {mStaticTextHit, notHilited, notDimmed, sizeable, noInset, 1000, dontPreferOutline, autoWrap, dontEraseFirst, justSystem, 1005, 4}, 
		NoSubviews}, 
	ViewSignatureAndClassname
		{'stat', 96, "", 'mous', notEnabled, noIdle, {}, MAThreeOh, 
		{70, 2}, {16, 82}, sizeVariable, sizeVariable, shown, doesntWantToBeTarget, 
		handlesCursor, letsSubViewsHandleCursor, noCursorID, 
		handlesHelp, letsSubViewsHandleHelp, noHelpID, 1, 
		NoDrawingEnvironment {}, 
		NoAdorners {}, emptyUserArea, 
		StaticText {mStaticTextHit, notHilited, notDimmed, sizeable, noInset, 1001, dontPreferOutline, autoWrap, dontEraseFirst, justSystem, 1005, 5}, 
		NoSubviews}, 
	ViewSignatureAndClassname
		{'stat', 96, "", 'numv', notEnabled, noIdle, {}, MAThreeOh, 
		{24, 23}, {15, 25}, sizeVariable, sizeVariable, shown, doesntWantToBeTarget, 
		handlesCursor, letsSubViewsHandleCursor, noCursorID, 
		handlesHelp, letsSubViewsHandleHelp, noHelpID, 1, 
		NoDrawingEnvironment {}, 
		AdornerListSignatureAndClassname {NoIdentifier, AdornerList, AdornerElementSize, AdornerElementSizeShift, DynamicArrayAllocationIncrement, {
			AdornFirst, AdornerSignatureAndClassname {'lntp', "TLINETOPADORNER", NoIdentifier, freeOnDeletion, $""}, 
			AdornFirst, AdornerSignatureAndClassname {'lnbo', "TLINEBOTTOMADORNER", NoIdentifier, freeOnDeletion, $""}, 
			AdornFirst, AdornerSignatureAndClassname {'lnrt', "TLINERIGHTADORNER", NoIdentifier, freeOnDeletion, $""}, 
			AdornFirst, AdornerSignatureAndClassname {'lnlf', "TLINELEFTADORNER", NoIdentifier, freeOnDeletion, $""}, 
			DrawView, AdornerLocalObject {DrawAdorner}, 
			AdornLast, AdornerSignatureAndClassname {'comp', CompatibilityAdorner, 'comp', freeOnDeletion, $"0F"}}}, emptyUserArea, 
		StaticText {mStaticTextHit, notHilited, notDimmed, sizeable, noInset, 1001, dontPreferOutline, autoWrap, dontEraseFirst, justSystem, 1005, 5}, 
		NoSubviews}, 
	ViewSignatureAndClassname
		{'stat', 96, "", 'numh', notEnabled, noIdle, {}, MAThreeOh, 
		{24, 66}, {15, 25}, sizeVariable, sizeVariable, shown, doesntWantToBeTarget, 
		handlesCursor, letsSubViewsHandleCursor, noCursorID, 
		handlesHelp, letsSubViewsHandleHelp, noHelpID, 1, 
		NoDrawingEnvironment {}, 
		AdornerListSignatureAndClassname {NoIdentifier, AdornerList, AdornerElementSize, AdornerElementSizeShift, DynamicArrayAllocationIncrement, {
			AdornFirst, AdornerSignatureAndClassname {'lntp', "TLINETOPADORNER", NoIdentifier, freeOnDeletion, $""}, 
			AdornFirst, AdornerSignatureAndClassname {'lnbo', "TLINEBOTTOMADORNER", NoIdentifier, freeOnDeletion, $""}, 
			AdornFirst, AdornerSignatureAndClassname {'lnrt', "TLINERIGHTADORNER", NoIdentifier, freeOnDeletion, $""}, 
			AdornFirst, AdornerSignatureAndClassname {'lnlf', "TLINELEFTADORNER", NoIdentifier, freeOnDeletion, $""}, 
			DrawView, AdornerLocalObject {DrawAdorner}, 
			AdornLast, AdornerSignatureAndClassname {'comp', CompatibilityAdorner, 'comp', freeOnDeletion, $"0F"}}}, emptyUserArea, 
		StaticText {mStaticTextHit, notHilited, notDimmed, sizeable, noInset, 1001, dontPreferOutline, autoWrap, dontEraseFirst, justSystem, 1005, 5}, 
		NoSubviews}
	}
};


// About Dialog resources + Views #################################################################################################################
// a couple of the resources are actually unused, but I left them in because I might need them
// in another project :-)


include "PICT.rsrc";					// PICT resource (1002)

resource 'STR#' (10006, "Window titles", purgeable) {
	{	/* array StringArray: 1 elements */
		/* [1] */
		"About MouseInfo"
	}
};

resource 'STR#' (10005, "Static Text text", purgeable) {
	{	/* array StringArray: 4 elements */
		/* [1] */
		"MouseInfo Sample App",
		/* [2] */
		"Information",
		/* [3] */
		"Version Info",
		/* [4] */
		"MouseInfo is a MacApp 3.1 TBehavior snippet - create, and handle events using behaviors (see Release Notes for info!).\nKent Sandvik/DTS (ALink: KSAND, Net: ksand@apple.com)",
		/* [5] */
		" ",
		/* [6] */
		"Kent & Jeff Sandvik, Bahia Honda, Key West, 1992"
	}
};

resource 'TxSt' (10000, purgeable) {
	tsBold,
	36,
	{	/* array: 3 elements */
		/* [1] */
		0x0,
		/* [2] */
		0x0,
		/* [3] */
		0x0
	},
	"Times"
};

resource 'TxSt' (10001, purgeable) {
	tsPlain,
	0,
	{	/* array: 3 elements */
		/* [1] */
		0x0,
		/* [2] */
		0x0,
		/* [3] */
		0x0
	},
	"Chicago"
};

resource 'TxSt' (1002, purgeable) {
	tsBold,
	9,
	{	/* array: 3 elements */
		/* [1] */
		0x0,
		/* [2] */
		0x0,
		/* [3] */
		0x0
	},
	"Monaco"
};

resource 'TxSt' (1003, purgeable) {
	tsBold,
	9,
	{	/* array: 3 elements */
		/* [1] */
		0xFFFF,
		/* [2] */
		0xFFFF,
		/* [3] */
		0xFFFF
	},
	"Monaco"
};

resource 'TxSt' (1004, purgeable) {
	tsBold,
	36,
	{	/* array: 3 elements */
		/* [1] */
		0xE604,
		/* [2] */
		0xFFFF,
		/* [3] */
		0x591C
	},
	"Times"
};




resource 'View' (12000, "About Box Window") {MAThreeOh, 
	{
	ViewSignatureAndClassname
		{'wind', 909, "", 'ATBW', enabled, noIdle, {}, MAThreeOh, 
		{45, 45}, {263, 435}, sizeFixed, sizeFixed, notShown, doesntWantToBeTarget, 
		handlesCursor, letsSubViewsHandleCursor, noCursorID, 
		handlesHelp, letsSubViewsHandleHelp, noHelpID, 1, 
		NoDrawingEnvironment {}, 
		AdornerListSignatureAndClassname {NoIdentifier, AdornerList, AdornerElementSize, AdornerElementSizeShift, DynamicArrayAllocationIncrement, {
			AdornFirst, AdornerLocalObject {EraseAdorner}, 
			DrawView, AdornerLocalObject {DrawAdorner}}}, emptyUserArea, 
		Window {noGrowDocProc, noID, goAwayBox, notResizable, doFirstClick, 
			freeOnClosing, disposeOnFree, doesntCloseDocument, dontOpenWithDocument, dontAdaptToScreen, dontStagger, forceOnScreen, 
			center, doesntFloat, doesntHideOnSuspend, generateActivates, filler, 10006, 1}, 7}, 
	ViewSignatureAndClassname
		{'stat', 96, "", 'stat', notEnabled, noIdle, {}, MAThreeOh, 
		{10, 25}, {39, 397}, sizeVariable, sizeVariable, shown, doesntWantToBeTarget, 
		handlesCursor, letsSubViewsHandleCursor, noCursorID, 
		handlesHelp, letsSubViewsHandleHelp, noHelpID, 1, 
		NoDrawingEnvironment {}, 
		NoAdorners {}, emptyUserArea, 
		StaticText {mStaticTextHit, notHilited, notDimmed, sizeable, noInset, 1004, dontPreferOutline, autoWrap, dontEraseFirst, justSystem, 10005, 1}, 
		NoSubviews}, 
	ViewSignatureAndClassname
		{'pict', 156, "TPicture", 'pict', notEnabled, noIdle, {}, MAThreeOh, 
		{50, 8}, {195, 265}, sizeVariable, sizeVariable, shown, doesntWantToBeTarget, 
		handlesCursor, letsSubViewsHandleCursor, noCursorID, 
		handlesHelp, letsSubViewsHandleHelp, noHelpID, 1, 
		NoDrawingEnvironment {}, 
		AdornerListSignatureAndClassname {NoIdentifier, AdornerList, AdornerElementSize, AdornerElementSizeShift, DynamicArrayAllocationIncrement, {
			DrawView, AdornerLocalObject {DrawAdorner}, 
			AdornAfter, AdornerSignatureAndClassname {'comp', "", 'comp', freeOnDeletion, $"0F"}}}, emptyUserArea, 
		Picture {mPictureHit, notHilited, notDimmed, sizeable, noInset, 10001, dontPreferOutline, 1002}, 
		NoSubviews}, 
	ViewSignatureAndClassname
		{'stat', 154, "", 'info', notEnabled, noIdle, {}, MAThreeOh, 
		{50, 287}, {16, 122}, sizeVariable, sizeVariable, shown, doesntWantToBeTarget, 
		handlesCursor, letsSubViewsHandleCursor, noCursorID, 
		handlesHelp, letsSubViewsHandleHelp, noHelpID, 1, 
		NoDrawingEnvironment {}, 
		AdornerListSignatureAndClassname {NoIdentifier, AdornerList, AdornerElementSize, AdornerElementSizeShift, DynamicArrayAllocationIncrement, {
			AdornFirst, AdornerLocalObject {EraseAdorner},
			DrawView, AdornerLocalObject {DrawAdorner}, 
			AdornAfter, AdornerSignatureAndClassname {'comp', "", 'comp', freeOnDeletion, $"8F"}}}, emptyUserArea, 
		StaticText {mStaticTextHit, notHilited, notDimmed, sizeable, noInset, 1002, dontPreferOutline, autoWrap, dontEraseFirst, justSystem, 10005, 2}, 
		NoSubviews}, 
	ViewSignatureAndClassname
		{'stat', 154, "", 'vers', notEnabled, noIdle, {}, MAThreeOh, 
		{200, 287}, {16, 122}, sizeVariable, sizeVariable, shown, doesntWantToBeTarget, 
		handlesCursor, letsSubViewsHandleCursor, noCursorID, 
		handlesHelp, letsSubViewsHandleHelp, noHelpID, 1, 
		NoDrawingEnvironment {}, 
		AdornerListSignatureAndClassname {NoIdentifier, AdornerList, AdornerElementSize, AdornerElementSizeShift, DynamicArrayAllocationIncrement, {
		AdornFirst, AdornerLocalObject {EraseAdorner},
		DrawView, AdornerLocalObject {DrawAdorner}, 
			AdornAfter, AdornerSignatureAndClassname {'comp', "", 'comp', freeOnDeletion, $"8F"}}}, emptyUserArea, 
		StaticText {mStaticTextHit, notHilited, notDimmed, sizeable, noInset, 1002, dontPreferOutline, autoWrap, dontEraseFirst, justSystem, 10005, 3}, 
		NoSubviews}, 
	ViewSignatureAndClassname
		{'stat', 96, "", 'sta1', notEnabled, noIdle, {}, MAThreeOh, 
		{70, 287}, {130, 144}, sizeVariable, sizeVariable, shown, doesntWantToBeTarget, 
		handlesCursor, letsSubViewsHandleCursor, noCursorID, 
		handlesHelp, letsSubViewsHandleHelp, noHelpID, 1, 
		NoDrawingEnvironment {}, 
		NoAdorners {}, emptyUserArea, 
		StaticText {mStaticTextHit, notHilited, notDimmed, sizeable, noInset, 1003, dontPreferOutline, autoWrap, dontEraseFirst, justSystem, 10005, 4}, 
		NoSubviews}, 
	ViewSignatureAndClassname
		{'stat', 96, "", 'sta2', notEnabled, noIdle, {}, MAThreeOh, 
		{225, 287}, {36, 144}, sizeVariable, sizeVariable, shown, doesntWantToBeTarget, 
		handlesCursor, letsSubViewsHandleCursor, noCursorID, 
		handlesHelp, letsSubViewsHandleHelp, noHelpID, 1, 
		NoDrawingEnvironment {}, 
		NoAdorners {}, emptyUserArea, 
		StaticText {mStaticTextHit, notHilited, notDimmed, sizeable, noInset, 1003, dontPreferOutline, autoWrap, dontEraseFirst, justSystem, 10005, 5}, 
		NoSubviews},
	ViewSignatureAndClassname
		{'stat', 96, "", 'sta3', notEnabled, noIdle, {}, MAThreeOh, 
		{248, 8}, {16, 360}, sizeVariable, sizeVariable, shown, doesntWantToBeTarget, 
		handlesCursor, letsSubViewsHandleCursor, noCursorID, 
		handlesHelp, letsSubViewsHandleHelp, noHelpID, 1, 
		NoDrawingEnvironment {}, 
		NoAdorners {}, emptyUserArea, 
		StaticText {mStaticTextHit, notHilited, notDimmed, sizeable, noInset, 1003, dontPreferOutline, autoWrap, dontEraseFirst, justSystem, 10005, 6}, 
		NoSubviews}, 
	}
};


