/*
 *	UMenuedWindow.cp
 *
 *	Copyright 1991 Imagenetics
 *	All rights reserved
 *
 *	19 Aug 91  EMB  Created file
 *	22 Aug 91  EMB  Modified design to be standalone unit
 *	 1 Oct 91  LPG  Changed Str255 to CStr255 (MacApp 3.02)
 *					Catch empty strings in AddToWindowMenu
 *
 */

#ifndef		__UMENUEDWINDOW__
#include	"UMenuedWindow.h"
#endif

#ifndef __UBEHAVIOR__
#include <UBehavior.h>
#endif

#ifndef __UAPPLICATION__
#include <UApplication.h>
#endif

#ifndef __UMENUMGR__
#include <UMenuMgr.h>
#endif

class TMenuedWindowBehavior : public TBehavior
{
	DeclareClass(TMenuedWindowBehavior);
	
private:
	TList*	fWindowsMenuData;

	short	fMenuID;
	short	fFirstItem;
public:

	// Construction/Destruction
	virtual void	Free();										//	OVERRIDE
	virtual void	IMenuedWindowBehavior(short menuID);

	TMenuedWindowBehavior() {this->Initialize();}
	virtual void	Initialize();								//	OVERRIDE

	// Menu Commands
	virtual void	DoMenuCommand(CommandNumber aCommand);		//	OVERRIDE
	virtual void	DoSetupMenus();								//	OVERRIDE

	// Window menu
	virtual void		AddToWindowMenu(TWindow* aWindow);
	virtual void		DeleteFromWindowMenu(TWindow* aWindow);
	virtual TWindow*	MenuItemToWindow(short menuItem);
	virtual void		SelectWindowMenuWindow(short itemNo);
	virtual short	WindowToMenuItem(TWindow* aWindow);
};


/*********************************************************************************************
	U M e n u e d W i n d o w    G l o b a l    R o u t i n e s
*********************************************************************************************/

TMenuedWindowBehavior*	gMenuedWindowBehavior = NULL;

//--------------------------------------------------------------------------------------------------
#pragma segment AInit

void InitUMenuedWindow(ResNumber menuID)
{
	gMenuedWindowBehavior = NULL;

	macroDontDeadStrip(TFloatMenuedWindow);
	macroDontDeadStrip(TMenuedWindow);

	if (gApplication == NULL)
	{
		if (qDebug)
			ProgramBreak("InitUMenuedWindow must be called in or after your IMyApplication method");
		Failure(minErr, 0);
	}

	gMenuedWindowBehavior = new TMenuedWindowBehavior;
	gMenuedWindowBehavior->IMenuedWindowBehavior(menuID);
	gApplication->AddBehavior(gMenuedWindowBehavior);
}

//--------------------------------------------------------------------------------------------------
/*
 *	In the spirit of SetCommandName and SetCommandIcon we have another utility
 *	routine to handle the menu item style
 */
#pragma segment MAUtilitiesRes

void SetCommandStyle(CommandNumber aCommand, short chStyle)
{
	ResNumber	menu;
	short		item;
	MenuHandle	aMenuHandle;

	aMenuHandle = CommandToComponents(aCommand, menu, item);
	if (aMenuHandle)
		::SetItemStyle(aMenuHandle, item, chStyle);
}


/*********************************************************************************************
	T M e n u e d W i n d o w C o H a n d l e r
*********************************************************************************************/

//--------------------------------------------------------------------------------------------------
#pragma segment ARes

#undef Inherited
#define Inherited TBehavior
DefineClass(TMenuedWindowBehavior, Inherited);

void TMenuedWindowBehavior::AddToWindowMenu(TWindow* aWindow)
{
	CStr255		itsTitle;

	aWindow->GetTitle(itsTitle);

	if (itsTitle.IsEmpty())
		itsTitle = " ";		// AppendMenu doesn't like empty strings.

	::AppendMenu(MAGetMenu(fMenuID), itsTitle);

	fWindowsMenuData->InsertLast(aWindow);
}


//--------------------------------------------------------------------------------------------------
#pragma segment ASelCommand

void TMenuedWindowBehavior::DoMenuCommand(CommandNumber aCommand)		// OVERRIDE
{
	short	itsMenuID;
	short	itsMenuItem;

	if (aCommand < 0)
	{
		CommandToMenuItem(aCommand, itsMenuID, itsMenuItem);
		if (itsMenuID == fMenuID)
			this->SelectWindowMenuWindow(itsMenuItem);
		else
			Inherited::DoMenuCommand(aCommand);
	}
	else
		Inherited::DoMenuCommand(aCommand);
}


//--------------------------------------------------------------------------------------------------
#pragma segment ARes

void TMenuedWindowBehavior::DoSetupMenus()		// OVERRIDE
{
	CommandNumber	itsCommandNumber;
	TWindow*		itsWindow = NULL;
	short			frontMenuItem;
	CStr255			itsTitle;
	short			itsMenuItem;
	short			i;

	Inherited::DoSetupMenus();

	//	Enable the variant portion of the windows menu
	frontMenuItem = this->WindowToMenuItem(gApplication->GetActiveWindow(false));
	for (i = short(fWindowsMenuData->GetSize()); i > 0; i--)
	{
		itsMenuItem = i + (fFirstItem - 1);
		itsCommandNumber = CommandFromMenuItem(fMenuID, itsMenuItem);
		itsWindow = this->MenuItemToWindow(itsMenuItem);

		//	Enable the item, checking if it is the front item
		EnableCheck(itsCommandNumber, true, itsMenuItem == frontMenuItem);

		//	Make sure the name is up-to-date
		itsWindow->GetTitle(itsTitle);
		SetCommandName(itsCommandNumber, itsTitle);

		//	Make the item style plain if it is visible, italics if hidden
		if (itsWindow->IsShown())
			SetCommandStyle(itsCommandNumber, normal);
		else
			SetCommandStyle(itsCommandNumber, italic);

		itsWindow = NULL;
	}
}

//--------------------------------------------------------------------------------------------------
#pragma segment ARes

void TMenuedWindowBehavior::DeleteFromWindowMenu(TWindow* aWindow)
{
	short	itsMenuItem;

	if (aWindow)
	{
		itsMenuItem = this->WindowToMenuItem(aWindow);

		if (itsMenuItem != kEmptyIndex)
			::DeleteMenuItem(MAGetMenu(fMenuID), itsMenuItem);

		fWindowsMenuData->Delete(aWindow);
	}
}

//--------------------------------------------------------------------------------------------------
#pragma segment ATerminate

void TMenuedWindowBehavior::Free()						// OVERRIDE
{
	fWindowsMenuData = (TList*)FreeIfObject(fWindowsMenuData);

	Inherited::Free();
}

//--------------------------------------------------------------------------------------------------
#pragma segment AInit

void TMenuedWindowBehavior::IMenuedWindowBehavior(short menuID)
{
	FailInfo	fi;

	this->IBehavior(kMenuedWindowBehavior);

	Try(fi)
	{
		fWindowsMenuData = NewList();
		if (qDebug)
			fWindowsMenuData->SetEltType("TWindow");

		fMenuID = menuID;
		fFirstItem = ::CountMItems(MAGetMenu(menuID)) + 1;

		fi.Success();
	}
	else
	{
		this->Free();
		fi.ReSignal();
	}
}

//--------------------------------------------------------------------------------------------------
#pragma segment AInit

void TMenuedWindowBehavior::Initialize()					// OVERRIDE
{
	fWindowsMenuData = NULL;
	fMenuID = 0;
	fFirstItem = 0;
}

//--------------------------------------------------------------------------------------------------
#pragma segment ARes

TWindow* TMenuedWindowBehavior::MenuItemToWindow(short menuItem)
{
	TWindow*	result = NULL;
	ArrayIndex	windowIndex;

	if (menuItem > 0)
	{
		windowIndex = menuItem - (fFirstItem - 1);
		if (windowIndex > kEmptyIndex  &&  windowIndex <= fWindowsMenuData->GetSize())
			result = (TWindow*)fWindowsMenuData->At(windowIndex);
	}

	return result;
}

//--------------------------------------------------------------------------------------------------
#pragma segment ARes

void TMenuedWindowBehavior::SelectWindowMenuWindow(short itemNo)
{
	TWindow*	itsWindow;

	if (itemNo > 0)
	{
		itsWindow = this->MenuItemToWindow(itemNo);
		if (itsWindow)
		{
			if (!itsWindow->IsShown())
				itsWindow->Open();
			itsWindow->Select();
		}
		else if (qDebug)
			ProgramBreak("Problem: Ive been asked to select a Windows menu window that doesnt exist");
	}
}

//--------------------------------------------------------------------------------------------------
#pragma segment ARes

short TMenuedWindowBehavior::WindowToMenuItem(TWindow* aWindow)
{
	short	result = 0;
	short	windowIndex;

	if (aWindow)
	{
		//	The fourth item is the first one placed in the windows menu (and hence
		//	tracked in fWindowsMenuData.
		windowIndex = short(fWindowsMenuData->GetIdentityItemNo(aWindow));
		if (windowIndex != kEmptyIndex)
			result = windowIndex + (fFirstItem - 1);
	}

	return result;
}

/*********************************************************************************************
	T F l o a t M e n u e d W i n d o w
*********************************************************************************************/

#pragma segment AOpen

#undef Inherited
#define Inherited TFloatWindow
DefineClass(TFloatMenuedWindow, Inherited);

void TFloatMenuedWindow::DoPostCreate(TDocument* itsDocument)		// OVERRIDE
{
	Inherited::DoPostCreate(itsDocument);

	if (gMenuedWindowBehavior)
		gMenuedWindowBehavior->AddToWindowMenu(this);
}

//--------------------------------------------------------------------------------------------------
#pragma segment AClose

void TFloatMenuedWindow::Free()										// OVERRIDE
{
	if (gMenuedWindowBehavior)
		gMenuedWindowBehavior->DeleteFromWindowMenu(this);

	Inherited::Free();
}

//--------------------------------------------------------------------------------------------------
#pragma segment AOpen

void TFloatMenuedWindow::IFloatMenuedWindow(TDocument* itsDocument,
									   WindowPtr itsWMgrWindow, Boolean canResize,
									   Boolean canClose, Boolean disposeOnFree)
{

	this->IFloatWindow(itsDocument, itsWMgrWindow, canResize, canClose, disposeOnFree);

	FailInfo	fi;
	Try(fi)
	{
		if (gMenuedWindowBehavior)
			gMenuedWindowBehavior->AddToWindowMenu(this);

		fi.Success();
	}
	else
	{
		this->Free();
		fi.ReSignal();
	}
}

/*********************************************************************************************
	T M e n u e d W i n d o w
*********************************************************************************************/
#pragma segment AOpen

#undef Inherited
#define Inherited TWindow
DefineClass(TMenuedWindow, Inherited);

void TMenuedWindow::DoPostCreate(TDocument* itsDocument)			// OVERRIDE
{
	Inherited::DoPostCreate(itsDocument);

	if (gMenuedWindowBehavior)
		gMenuedWindowBehavior->AddToWindowMenu(this);
}


//--------------------------------------------------------------------------------------------------
#pragma segment AClose

void TMenuedWindow::Free()										// OVERRIDE
{
	if (gMenuedWindowBehavior)
		gMenuedWindowBehavior->DeleteFromWindowMenu(this);

	Inherited::Free();
}

//--------------------------------------------------------------------------------------------------
#pragma segment AOpen

void TMenuedWindow::IMenuedWindow(TDocument* itsDocument, WindowPtr itsWMgrWindow,
							 Boolean canResize, Boolean canClose,
							 Boolean disposeOnFree)
{

	this->IWindow(itsDocument, itsWMgrWindow, canResize, canClose, disposeOnFree);

	FailInfo	fi;
	Try(fi)
	{
		if (gMenuedWindowBehavior)
			gMenuedWindowBehavior->AddToWindowMenu(this);

		fi.Success();
	}
	else
	{
		this->Free();
		fi.ReSignal();
	}
}
