// Copyright  1991 by Apple Computer, Inc.  All rights reserved. 
// Windoid.r file.

// INCLUDES ---------------------------------------------------------------------------------
// Auto-Include the requirements for this source

#ifndef __TYPES.R__
#include "Types.r"
#endif

#ifndef __SYSTYPES.R__
#include "SysTypes.r"				// needed for version resource
#endif		

#ifndef __MacAppTypes__
#include "MacAppTypes.r"
#endif

#if qTemplateViews
#ifndef __ViewTypes__
#include "ViewTypes.r"
#endif
#endif

#if qDebug
include "Debug.rsrc";
#endif

#include "WindoidRez.h"				// common header file for resource IDs


// RESOURCES -------------------------------------------------------------------------------

include "MacApp.rsrc";
include "Printing.rsrc";
include "FloatWindow.rsrc";			// floating window resources


// CODE ------------------------------------------------------------------------------------

#if !qPowerPC
include $$Shell("ObjApp")"Windoid" 'CODE';
#endif


// SIZE ------------------------------------------------------------------------------------

resource 'SIZE' (-1) {
	saveScreen,
	acceptSuspendResumeEvents,
	enableOptionSwitch,
	canBackground,
	doesActivateOnFGSwitch,
	backgroundAndForeground,
	dontGetFrontClicks,
	ignoreAppDiedEvents,
	is32BitCompatible,
	isHighLevelEventAware,
	localAndRemoteHLEvents,
	isStationeryAware,				
	reserved,
	reserved,
	reserved,
	reserved,
#if qModelFarCode
	1550 * 1024,
	1500 * 1024,
#elif qDebug
	1500 * 1024,
	1475 * 1024
#else
	1375 * 1024,
	1350 * 1024
#endif
};

/*--------------------------------------------------------------------------------
	memory stuff
--------------------------------------------------------------------------------*/
resource 'mem!' (132,
#if qNames
	"Additional Stack Space",
#endif
	purgeable) {
	0,				// Add to object heap size
	0,				// Add to heap increment size
	0,				// Add to temporary reserve
	0,				// Add to permanent reserve
	49152			// Add to stack space
};



/*	Printing to the LaserWriter is the time when the most temporary memory
	is in use.  We need the segments in use at that time */

resource 'seg!' (256, purgeable) {
	{
		"GNonRes";
		"GClipboard";
		"GClose";
		"GFile";
		"GOpen";
		"GReadFile";
		"GSelCommand";
		"GFinder";
		"GWriteFile";
		"BBNonRes";
		"BBOpen";
		"GNonRes2";
		"GPrint";
		"GReadResource";
		"TESelCommand";
	}
};

#if qPowerPC
#include "CodeFragmentTypes.r"

resource 'cfrg' (0, "Configuration Info") {
	{
		kPowerPC,
		kFullLib,
		kNoVersionNum,
		kNoVersionNum,
		0,
		0,
		kIsApp,
		kOnDiskFlat,
		kZeroOffset,
		kWholeFork,
		"Windoid"
	}
};
#endif


// VERS ------------------------------------------------------------------------------------
// Get the default Version resources

include "Defaults.rsrc"  'vers' (1);				// application or file specific


// ALERTS AND DLOGS ------------------------------------------------------------------------

include "Defaults.rsrc" 'ALRT'	(phAboutApp);		// About window
include "Defaults.rsrc" 'DITL'	(phAboutApp);		// About contents
include "Defaults.rsrc" 'STR#'	(kDefaultCredits);	// credits


// ICONs and BUNDLEs -----------------------------------------------------------------------
// Get the default MacApp application icon and file reference

include "Defaults.rsrc"  'ICN#' (128);
include "Defaults.rsrc"  'FREF' (128);


// CMNUs -----------------------------------------------------------------------------------

include "Defaults.rsrc" 'CMNU' (mApple);			// grab the default Apple/File menus

resource 'CMNU' (mFile,
#if qNames
"mFile",
#endif
nonpurgeable) {
	mFile,
	textMenuProc,
	EnablingManagedByMacApp,
	enabled,
	"File",
	{
	"New",				noIcon, "N",	noMark, plain, cNew;
	"Close",			noIcon, "W",	noMark, plain, cClose;
	"-",				noIcon, noKey,	noMark, plain, nocommand;
	"Quit",				noIcon, "Q",	noMark, plain, cQuit
	}
};


resource 'CMNU' (mWindoid,
#if qNames
"mWindoid",
#endif
nonpurgeable) {
	mWindoid,
	textMenuProc,
	EnablingManagedByMacApp,
	enabled,
	"Windoid",
	 {
	"Green",			noIcon, noKey, noMark, plain, cGreen;
	"Yellow",			noIcon, noKey, noMark, plain, cYellow;
	"Red",				noIcon, noKey, noMark, plain, cRed;
	}
};

resource 'CMNU' (mNormalMenu,
#if qNames
"mNormalMenu",
#endif
nonpurgeable) {
	mNormalMenu,
	textMenuProc,
	EnablingManagedByMacApp,
	enabled,
	"Set Light",
	 {
	/* [1] */	"Green",				noIcon, "G", noMark, plain, cNormGreen;
	/* [2] */	"Yellow",				noIcon, "Y", noMark, plain, cNormYellow;
	/* [3] */	"Red",					noIcon, "R", noMark, plain, cNormRed
	}
};


// MBARs -----------------------------------------------------------------------------------
// Displayed menus 

resource 'MBAR' (kMBarDisplayed,
#if qNames
"Windoid",
#endif
	purgeable) {
	{mApple; mFile; mWindoid; mNormalMenu}
	
};


resource 'TxSt' (1000, purgeable) {
	tsPlain,
	0,
	{	/* array: 3 elements */
		/* [1] */
		0x0,
		/* [2] */
		0x0,
		/* [3] */
		0x0
	},
	"Chicago"
};


resource 'View' (1001, purgeable) {MAThreeOh, 
	{
	ViewSignatureAndClassname
		{'wind', 647, "", 'WIND', enabled, noIdle, {}, MAThreeOh, 
		{50, 20}, {200, 350}, sizeVariable, sizeVariable, shown, doesntWantToBeTarget, 
		handlesCursor, letsSubViewsHandleCursor, noCursorID, 
		handlesHelp, letsSubViewsHandleHelp, noHelpID, 1, 
		NoDrawingEnvironment {}, 
		AdornerListSignatureAndClassname {NoIdentifier, AdornerList, AdornerElementSize, AdornerElementSizeShift, DynamicArrayAllocationIncrement, {
			AdornFirst, AdornerLocalObject {EraseAdorner}, 
			DrawView, AdornerLocalObject {DrawAdorner}, 
			AdornLast, AdornerLocalObject {ResizeIconAdorner}}}, emptyUserArea, 
		Window {zoomDocProc, 'DFLT', goAwayBox, resizable, ignoreFirstClick, 
			freeOnClosing, disposeOnFree, closesDocument, openWithDocument, dontAdaptToScreen, stagger, forceOnScreen, 
			dontCenter, doesntFloat, doesntHideOnSuspend, generateActivates, filler, 1006, 2}, 3}, 
	ViewSignatureAndClassname
		{'scrl', 183, "", 'SCLR', enabled, noIdle, {}, MAThreeOh, 
		{0, 0}, {185, 335}, sizeRelSuperView, sizeRelSuperView, shown, doesntWantToBeTarget, 
		handlesCursor, letsSubViewsHandleCursor, noCursorID, 
		handlesHelp, letsSubViewsHandleHelp, noHelpID, 1, 
		NoDrawingEnvironment {}, 
		NoAdorners {}, emptyUserArea, 
		Scroller {'vCLR', 'hCLR', {150, 320}, {16, 16}, VertConstrain, HorzConstrain, noInset, respondsToFKeys}, 1}, 
	ViewSignatureAndClassname
		{'inc@', 72, "", noID, notEnabled, noIdle, {}, MAThreeOh, 
		{0, 0}, {150, 320}, sizeFixed, sizeFixed, shown, doesntWantToBeTarget, 
		handlesCursor, letsSubViewsHandleCursor, noCursorID, 
		handlesHelp, letsSubViewsHandleHelp, noHelpID, 1, 
		NoDrawingEnvironment {}, 
		NoAdorners {}, emptyUserArea, 
		IncludeAt {1002, {0, 0}}, 
		NoSubviews}, 
	ViewSignatureAndClassname
		{'ssbr', 159, "", 'hCLR', enabled, noIdle, {}, MAThreeOh, 
		{185, -1}, {16, 337}, sizeVariable, sizeVariable, shown, doesntWantToBeTarget, 
		handlesCursor, letsSubViewsHandleCursor, noCursorID, 
		handlesHelp, letsSubViewsHandleHelp, noHelpID, 1, 
		NoDrawingEnvironment {}, 
		AdornerListSignatureAndClassname {NoIdentifier, AdornerList, AdornerElementSize, AdornerElementSizeShift, DynamicArrayAllocationIncrement, {
			DrawView, AdornerLocalObject {DrawAdorner}, 
			AdornAfter, AdornerSignatureAndClassname {'comp', "", 'comp', freeOnDeletion, $"02"}}}, emptyUserArea, 
		ScrollerScrollBar {mHScrollBarHit, notHilited, notDimmed, sizeable, noInset, 1000, dontPreferOutline, h, 0, 0, 0}, 
		NoSubviews}, 
	ViewSignatureAndClassname
		{'ssbr', 159, "", 'vCLR', enabled, noIdle, {}, MAThreeOh, 
		{-1, 335}, {187, 16}, sizeVariable, sizeVariable, shown, doesntWantToBeTarget, 
		handlesCursor, letsSubViewsHandleCursor, noCursorID, 
		handlesHelp, letsSubViewsHandleHelp, noHelpID, 1, 
		NoDrawingEnvironment {}, 
		AdornerListSignatureAndClassname {NoIdentifier, AdornerList, AdornerElementSize, AdornerElementSizeShift, DynamicArrayAllocationIncrement, {
			DrawView, AdornerLocalObject {DrawAdorner}, 
			AdornAfter, AdornerSignatureAndClassname {'comp', "", 'comp', freeOnDeletion, $"02"}}}, emptyUserArea, 
		ScrollerScrollBar {mVScrollBarHit, notHilited, notDimmed, sizeable, noInset, 1000, dontPreferOutline, v, 0, 0, 0}, 
		NoSubviews}
	}
};

resource 'View' (1002, purgeable) {MAThreeOh, 
	{
	ViewSignatureAndClassname
		{'dflt', 62, "", 'DFLT', enabled, noIdle, {}, MAThreeOh, 
		{0, 0}, {150, 320}, sizeFixed, sizeFixed, shown, doesntWantToBeTarget, 
		handlesCursor, letsSubViewsHandleCursor, noCursorID, 
		handlesHelp, letsSubViewsHandleHelp, noHelpID, 1, 
		NoDrawingEnvironment {}, 
		NoAdorners {}, emptyUserArea, 
		View {}, 
		NoSubviews}
	}
};


resource 'View' (1007, purgeable) {MAThreeOh, 
	{
	ViewSignatureAndClassname
		{'fwnd', 214, "TFloatWindow", 'TWND', enabled, noIdle, {}, MAThreeOh, 
		{80, 80}, {kLightPaletteHeight, kLightPaletteWidth}, sizeFixed, sizeFixed, shown, doesntWantToBeTarget, 
		handlesCursor, letsSubViewsHandleCursor, noCursorID, 
		handlesHelp, letsSubViewsHandleHelp, noHelpID, 1, 
		NoDrawingEnvironment {}, 
		AdornerListSignatureAndClassname {NoIdentifier, AdornerList, AdornerElementSize, AdornerElementSizeShift, DynamicArrayAllocationIncrement, {
			AdornFirst, AdornerLocalObject {EraseAdorner}, 
			DrawView, AdornerLocalObject {DrawAdorner}}}, emptyUserArea, 
		FloatWindow {kWindoidWDEF + kWindoidNotResizable, noID, goAwayBox, notResizable, doFirstClick, 
			dontFreeOnClosing, dontDisposeOnFree, doesntCloseDocument, dontOpenWithDocument, dontAdaptToScreen, dontStagger, forceOnScreen, 
			dontCenter, floats, hidesOnSuspend, doesntGenerateActivates, filler, 1006, 1}, 1}, 
	ViewSignatureAndClassname
		{'view', 75, "TLightPalette", 'TPLT', enabled, noIdle, {}, MAThreeOh, 
		{0, 0}, {kLightPaletteHeight, kLightPaletteWidth}, sizeFixed, sizeFixed, shown, doesntWantToBeTarget, 
		handlesCursor, letsSubViewsHandleCursor, noCursorID, 
		handlesHelp, letsSubViewsHandleHelp, noHelpID, 1, 
		NoDrawingEnvironment {}, 
		NoAdorners {}, emptyUserArea, 
		View {}, 
		NoSubviews}
	}
};
